@@ -6,6 +6,7 @@ from itertools import groupby
 from typing import List, Optional, Union, cast
 
 import pandas as pd
+from croniter import croniter
 
 import feast
 from feast.config import Config
@@ -21,8 +22,10 @@ from feast_spark.api.JobService_pb2 import (
     GetHistoricalFeaturesRequest,
     GetJobRequest,
     ListJobsRequest,
+    ScheduleOfflineToOnlineIngestionJobRequest,
     StartOfflineToOnlineIngestionJobRequest,
     StartStreamToOnlineIngestionJobRequest,
+    UnscheduleOfflineToOnlineIngestionJobRequest,
 )
 from feast_spark.api.JobService_pb2_grpc import JobServiceStub
 from feast_spark.constants import ConfigOptions as opt
@@ -30,10 +33,12 @@ from feast_spark.pyspark.abc import RetrievalJob, SparkJob
 from feast_spark.pyspark.launcher import (
     get_job_by_id,
     list_jobs,
+    schedule_offline_to_online_ingestion,
     start_historical_feature_retrieval_job,
     start_historical_feature_retrieval_spark_session,
     start_offline_to_online_ingestion,
     start_stream_to_online_ingestion,
+    unschedule_offline_to_online_ingestion,
 )
 from feast_spark.remote_job import (
     RemoteBatchIngestionJob,
@@ -305,6 +310,61 @@ class Client:
                 response.log_uri,
             )
 
+    def schedule_offline_to_online_ingestion(
+        self,
+        feature_table: feast.FeatureTable,
+        ingestion_timespan: int,
+        cron_schedule: str,
+    ):
+        """
+        Launch Scheduled Ingestion Job from Batch Source to Online Store for given feature table
+
+        Args:
+            feature_table:  FeatureTable that will be ingested into the online store
+            ingestion_timespan: Days of data which will be ingestion per job. The boundaries
+                on which to filter the source are [end of day of execution date - ingestion_timespan (days) ,
+                end of day of execution date)
+            cron_schedule: Cron schedule expression
+
+        Returns: Spark Job Proxy object
+        """
+        if not croniter.is_valid(cron_schedule):
+            raise RuntimeError(f"{cron_schedule} is not a valid cron expression")
+        if not self._use_job_service:
+            schedule_offline_to_online_ingestion(
+                client=self,
+                project=self._feast.project,
+                feature_table=feature_table,
+                ingestion_timespan=ingestion_timespan,
+                cron_schedule=cron_schedule,
+            )
+        else:
+            request = ScheduleOfflineToOnlineIngestionJobRequest(
+                project=self._feast.project,
+                table_name=feature_table.name,
+                ingestion_timespan=ingestion_timespan,
+                cron_schedule=cron_schedule,
+            )
+            self._job_service.ScheduleOfflineToOnlineIngestionJob(request)
+
+    def unschedule_offline_to_online_ingestion(
+        self, feature_table: feast.FeatureTable, project=None
+    ):
+        feature_table_project = self._feast.project if project is None else project
+
+        if not self._use_job_service:
+            unschedule_offline_to_online_ingestion(
+                client=self,
+                project=feature_table_project,
+                feature_table=feature_table.name,
+            )
+        else:
+            request = UnscheduleOfflineToOnlineIngestionJobRequest(
+                project=feature_table_project, table_name=feature_table.name,
+            )
+
+            self._job_service.UnscheduleOfflineToOnlineIngestionJob(request)
+
     def start_stream_to_online_ingestion(
         self,
         feature_table: feast.FeatureTable,
