@@ -18,6 +18,7 @@ from feast_spark.pyspark.abc import (
     JobLauncher,
     RetrievalJob,
     RetrievalJobParameters,
+    ScheduledBatchIngestionJobParameters,
     SparkJob,
     SparkJobFailure,
     SparkJobStatus,
@@ -27,6 +28,7 @@ from feast_spark.pyspark.abc import (
 
 from .k8s_utils import (
     DEFAULT_JOB_TEMPLATE,
+    DEFAULT_SCHEDULED_JOB_TEMPLATE,
     HISTORICAL_RETRIEVAL_JOB_TYPE,
     LABEL_FEATURE_TABLE,
     LABEL_FEATURE_TABLE_HASH,
@@ -42,7 +44,10 @@ from .k8s_utils import (
     _get_job_by_id,
     _list_jobs,
     _prepare_job_resource,
+    _prepare_scheduled_job_resource,
     _submit_job,
+    _submit_scheduled_job,
+    _unschedule_job,
 )
 
 
@@ -57,6 +62,17 @@ def _generate_job_id() -> str:
     )
 
 
+def _generate_scheduled_job_id(project: str, feature_table_name: str) -> str:
+    scheduled_job_id = f"feast-{project}-{feature_table_name}".replace("_", "-")
+    k8s_res_name_char_limit = 253
+
+    return (
+        scheduled_job_id
+        if len(scheduled_job_id) <= k8s_res_name_char_limit
+        else scheduled_job_id[:k8s_res_name_char_limit]
+    )
+
+
 def _truncate_label(label: str) -> str:
     return label[:63]
 
@@ -189,6 +205,9 @@ class KubernetesJobLauncher(JobLauncher):
             self._resource_template = _load_resource_template(resource_template_path)
         else:
             self._resource_template = yaml.safe_load(DEFAULT_JOB_TEMPLATE)
+        self._scheduled_resource_template = yaml.safe_load(
+            DEFAULT_SCHEDULED_JOB_TEMPLATE
+        )
 
     def _job_from_job_info(self, job_info: JobInfo) -> SparkJob:
         if job_info.job_type == HISTORICAL_RETRIEVAL_JOB_TYPE:
@@ -352,6 +371,65 @@ class KubernetesJobLauncher(JobLauncher):
 
         return cast(BatchIngestionJob, self._job_from_job_info(job_info))
 
+    def schedule_offline_to_online_ingestion(
+        self, ingestion_job_params: ScheduledBatchIngestionJobParameters
+    ):
+        """
+        Schedule a batch ingestion job using Spark Operator.
+
+        Raises:
+            SparkJobFailure: Failure to create the ScheduleSparkApplication resource, or timeout.
+
+        Returns:
+            ScheduledBatchIngestionJob: wrapper around remote job that can be used to check the job id.
+        """
+
+        jar_s3_path = self._upload_jar(ingestion_job_params.get_main_file_path())
+
+        schedule_job_id = _generate_scheduled_job_id(
+            project=ingestion_job_params.get_project(),
+            feature_table_name=ingestion_job_params.get_feature_table_name(),
+        )
+
+        resource = _prepare_scheduled_job_resource(
+            scheduled_job_template=self._scheduled_resource_template,
+            scheduled_job_id=schedule_job_id,
+            job_template=self._resource_template,
+            job_type=OFFLINE_TO_ONLINE_JOB_TYPE,
+            main_application_file=jar_s3_path,
+            main_class=ingestion_job_params.get_class_name(),
+            packages=[BQ_SPARK_PACKAGE],
+            jars=[],
+            extra_metadata={},
+            azure_credentials=self._get_azure_credentials(),
+            arguments=ingestion_job_params.get_arguments(),
+            namespace=self._namespace,
+            extra_labels={
+                LABEL_FEATURE_TABLE: _truncate_label(
+                    ingestion_job_params.get_feature_table_name()
+                ),
+                LABEL_FEATURE_TABLE_HASH: _generate_project_table_hash(
+                    ingestion_job_params.get_project(),
+                    ingestion_job_params.get_feature_table_name(),
+                ),
+                LABEL_PROJECT: ingestion_job_params.get_project(),
+            },
+        )
+
+        _submit_scheduled_job(
+            api=self._api,
+            name=schedule_job_id,
+            resource=resource,
+            namespace=self._namespace,
+        )
+
+    def unschedule_offline_to_online_ingestion(self, project: str, feature_table: str):
+        _unschedule_job(
+            api=self._api,
+            namespace=self._namespace,
+            resource_name=_generate_scheduled_job_id(project, feature_table),
+        )
+
     def start_stream_to_online_ingestion(
         self, ingestion_job_params: StreamIngestionJobParameters
     ) -> StreamIngestionJob:
